@@ -583,3 +583,30 @@ class TestOLT(unittest.TestCase):
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
         })
+
+    def test_bridge_mapping_disabled(self):
+        """PPA-664 bridge mapping is enabled by default but can be disabled."""
+        self.setup_simple_network(bridged_macs=True)
+        self.ctx.bridge_mapping_enabled = None
+        self.run_poll()
+        cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
+        self.assertEqual(len(cpe_mac_refs), 7)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
+            '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
+        })
+
+        self.ctx.bridge_mapping_enabled = False
+        self.run_poll()
+        self.assertEqual(len(cpe_mac_refs), 3)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1.100001', 'sm': '00:00:02:00:00:01', 'serial_service': '000002000001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:02', 'serial_service': '000002000002'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
+        })
